@@ -1,5 +1,5 @@
 document.getElementById("Contents").innerHTML='\
-    <ul><li><input type="checkbox" id="07"><label for="07">Makroar og programmering</label><ul>\
+    <ul><li><input type="checkbox" id="07"><label for="07">Makroar og skriptlaging</label><ul>\
     <li><input type="checkbox" id="0701"><label for="0701">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
     <li><a target="_top" href="nn/text/sbasic/shared/main0601.html">Hjelp for LibreOffice Basic</a></li>\
     <li><a target="_top" href="nn/text/sbasic/shared/01000000.html">Programmering i LibreOffice Basic</a></li>\
@@ -124,6 +124,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/sbasic/shared/03090202.html">For...Next-uttrykket</a></li>\
     <li><a target="_top" href="nn/text/sbasic/shared/03120301.html">Format-funksjonen</a></li>\
     <li><a target="_top" href="nn/text/sbasic/shared/03150000.html">FormatDateTime-funksjonen [VBA]</a></li>\
+    <li><a target="_top" href="nn/text/sbasic/shared/03170010.html">FormatNumber-funksjonen [VBA]</a></li>\
     <li><a target="_top" href="nn/text/sbasic/shared/03020102.html">FreeFile-funksjonen</a></li>\
     <li><a target="_top" href="nn/text/sbasic/shared/03090405.html">FreeLibrary-funksjonen</a></li>\
     <li><a target="_top" href="nn/text/sbasic/shared/03090406.html">Function-uttrykket</a></li>\
@@ -297,7 +298,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/sbasic/guide/access2base.html">Access2Base</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="08"><label for="08">Rekneark</label><ul>\
+    <ul><li><input type="checkbox" id="08"><label for="08">Rekneark (Calc)</label><ul>\
     <li><input type="checkbox" id="0801"><label for="0801">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
     <li><a target="_top" href="nn/text/scalc/main0000.html">Velkommen til hjelp for LibreOffice Calc</a></li>\
     <li><a target="_top" href="nn/text/scalc/main0503.html">LibreOffice Calc-funksjonar</a></li>\
@@ -477,7 +478,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/schart/04/01020000.html">Snartastar for diagram</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="01"><label for="01">Installering</label><ul>\
+    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice Innstallering</label><ul>\
     <li><a target="_top" href="nn/text/shared/guide/ms_doctypes.html">Endra filtilknyting for Microsoft Office-dokumenttypar</a></li>\
     <li><a target="_top" href="nn/text/shared/01/profile_safe_mode.html">Sikker modus</a></li>\
 	</ul></li></ul>\
@@ -503,7 +504,6 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/shared/optionen/01010200.html">Generelt</a></li>\
     <li><a target="_top" href="nn/text/shared/optionen/01010300.html">Stiar</a></li>\
     <li><a target="_top" href="nn/text/shared/optionen/01010400.html">Skrivestøtte</a></li>\
-    <li><a target="_top" href="nn/text/shared/optionen/01010500.html">Farge</a></li>\
     <li><a target="_top" href="nn/text/shared/optionen/01010600.html">Generelt</a></li>\
     <li><a target="_top" href="nn/text/shared/optionen/01010700.html">Skrifttypar</a></li>\
     <li><a target="_top" href="nn/text/shared/optionen/01010800.html">Vis</a></li>\
@@ -661,7 +661,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/shared/guide/numbering_stop.html">Slå av punktmerking og nummerering i enkelte avsnitt</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="09"><label for="09">Databasefunksjonar</label><ul>\
+    <ul><li><input type="checkbox" id="09"><label for="09">Databasefunksjonar (Base)</label><ul>\
     <li><input type="checkbox" id="0901"><label for="0901">Generell informasjon</label><ul>\
     <li><a target="_top" href="nn/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
     <li><a target="_top" href="nn/text/shared/guide/database_main.html">Databaseoversikt</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/shared/guide/data_enter_sql.html">Køyra SQL-kommandoar</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">Presentasjonar og teikningar</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">Presentasjonar og teikning (Impress/Draw)</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
     <li><a target="_top" href="nn/text/simpress/main0000.html">Velkommen til hjelp for LibreOffice Impress</a></li>\
     <li><a target="_top" href="nn/text/sdraw/main0000.html">Velkommen til hjelp for LibreOffice Draw</a></li>\
@@ -820,7 +820,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/simpress/guide/rehearse_timings.html">Øv på tidsbruk og lysbiletskift</a></li>\
          </ul></li>\
      </ul></li></ul>\
-    <ul><li><input type="checkbox" id="03"><label for="03">Formlar</label><ul>\
+    <ul><li><input type="checkbox" id="03"><label for="03">Formlar (Math)</label><ul>\
     <li><input type="checkbox" id="0301"><label for="0301">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
     <li><a target="_top" href="nn/text/smath/main0000.html">Velkommen til hjelp for LibreOffice Math</a></li>\
     <li><a target="_top" href="nn/text/smath/main0503.html">Funksjonar i LibreOffice Math</a></li>\
@@ -840,7 +840,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/smath/guide/parentheses.html">Setja inn parentesar</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="02"><label for="02">Tekstdokument</label><ul>\
+    <ul><li><input type="checkbox" id="02"><label for="02">Tekstdokument (Writer)</label><ul>\
     <li><input type="checkbox" id="0201"><label for="0201">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
     <li><a target="_top" href="nn/text/swriter/main0000.html">Velkommen til hjelp for LibreOffice Writer</a></li>\
     <li><a target="_top" href="nn/text/swriter/main0503.html">Funksjonalitet i LibreOffice Writer</a></li>\
@@ -860,7 +860,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/swriter/main0105.html">Format</a></li>\
     <li><a target="_top" href="nn/text/swriter/main0115.html">Stilar</a></li>\
     <li><a target="_top" href="nn/text/swriter/main0110.html">Tabell</a></li>\
-    <li><a target="_top" href="nn/text/swriter/main0120.html">Form Menu</a></li>\
+    <li><a target="_top" href="nn/text/swriter/main0120.html">Skjemameny</a></li>\
     <li><a target="_top" href="nn/text/swriter/main0106.html">Verktøy</a></li>\
     <li><a target="_top" href="nn/text/swriter/main0107.html">Vindauge</a></li>\
     <li><a target="_top" href="nn/text/shared/main0108.html">Hjelp</a></li>\
@@ -1049,7 +1049,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nn/text/shared/01/02100001.html">Liste over regulære uttrykk</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="06"><label for="06">HTML-dokument</label><ul>\
+    <ul><li><input type="checkbox" id="06"><label for="06">HTML-dokument (Writer)</label><ul>\
     <li><a target="_top" href="nn/text/shared/07/09000000.html">Vevsider</a></li>\
     <li><a target="_top" href="nn/text/shared/02/01170700.html">HTML-filter og skjema</a></li>\
     <li><a target="_top" href="nn/text/swriter/guide/send2html.html">Lagra tekstdokument i HTML-format</a></li>\
